@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,16 +66,42 @@ import java.util.ListResourceBundle;
 public class FormatData_es_BO extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_AmPmMarkers = new String[] {
-               "a.\u00a0m.",
-               "p.\u00a0m.",
-            };
+        final String[] metaValue_generic_narrow_AmPmMarkers = new String[] {
+            "a.\u202fm.",
+            "p.\u202fm.",
+            "",
+            "del mediod\u00eda",
+            "de la madrugada",
+            "de la ma\u00f1ana",
+            "",
+            "",
+            "de la tarde",
+            "",
+            "de la noche",
+            "",
+        };
+        final String[] metaValue_generic_AmPmMarkers = new String[] {
+            "a.\u00a0m.",
+            "p.\u00a0m.",
+            "",
+            "del mediod\u00eda",
+            "de la madrugada",
+            "de la ma\u00f1ana",
+            "",
+            "",
+            "de la tarde",
+            "",
+            "de la noche",
+            "",
+        };
         final Object[][] data = new Object[][] {
-            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
-            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "AmPmMarkers", metaValue_AmPmMarkers },
+            { "generic.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "generic.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "generic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "field.dayperiod", "a.\u00a0m./p.\u00a0m." },
             { "DatePatterns",
                 new String[] {
                     "EEEE, d 'de' MMMM 'de' y",
@@ -88,6 +110,15 @@ public class FormatData_es_BO extends ListResourceBundle {
                     "d/M/yy",
                 }
             },
+            { "buddhist.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "japanese.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "roc.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -105,20 +136,14 @@ public class FormatData_es_BO extends ListResourceBundle {
                     "",
                 }
             },
-            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
                     "\u00a4#,##0.00",
-                    "#,##0\u00a0%",
-                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "",
                 }
             },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "field.dayperiod", "a.\u00a0m./p.\u00a0m." },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
         };
         return data;
     }
